ebma_mc_draws is called from within ebma. It tunes using
multiple cores.
ebma_mc_draws(
train.preds,
train.y,
ebma.fold,
y,
L1.x,
L2.x,
L2.unit,
L2.reg,
pc.names,
model.bs,
model.pca,
model.lasso,
model.gb,
model.svm,
model.mrp,
model_deep,
tol,
n.draws,
cores
)The classifier weights. A numeric vector.
Predictions of classifiers on the classifier training data. A tibble.
Outcome variable of the classifier training data. A numeric vector.
New data for EBMA tuning. A list containing the the data that must not have been used in classifier training.
Outcome variable. A character vector containing the column names of
the outcome variable. A character scalar containing the column name of
the outcome variable in survey.
Individual-level covariates. A character vector containing the
column names of the individual-level variables in survey and
census used to predict outcome y. Note that geographic unit
is specified in argument L2.unit.
Context-level covariates. A character vector containing the
column names of the context-level variables in survey and
census used to predict outcome y. To exclude context-level
variables, set L2.x = NULL.
Geographic unit. A character scalar containing the column
name of the geographic unit in survey and census at which
outcomes should be aggregated.
Geographic region. A character scalar containing the column
name of the geographic region in survey and census by which
geographic units are grouped (L2.unit must be nested within
L2.reg). Default is NULL.
Principal Component Variable names. A character vector containing the names of the context-level principal components variables.
The tuned model from the multilevel regression with best
subset selection classifier. An glmer object.
The tuned model from the multilevel regression with
principal components as context-level predictors classifier. An
glmer object.
The tuned model from the multilevel regression with L1
regularization classifier. A glmmLasso object.
The tuned model from the gradient boosting classifier. A
gbm object.
The tuned model from the support vector machine classifier.
An svm object.
The standard MrP model. An glmer object
The tuned model from the deep mrp classifier. An
vglmer object.
EBMA tolerance. A numeric vector containing the tolerance values
for improvements in the log-likelihood before the EM algorithm stops
optimization. Values should range at least from \(0.01\) to \(0.001\).
Default is c(0.01, 0.005, 0.001, 0.0005, 0.0001, 0.00005, 0.00001).
Passed on from ebma.tol.
EBMA number of samples. An integer-valued scalar specifying
the number of bootstrapped samples to be drawn from the EBMA fold and used
for tuning EBMA. Default is \(100\). Passed on from ebma.n.draws.
The number of cores to be used. An integer indicating the number of processor cores used for parallel computing. Default is 1.