summary.autoMrP() ...
# S3 method for autoMrP
summary(
object,
ci.lvl = 0.95,
digits = 4,
format = "simple",
classifiers = NULL,
n = 10,
...
)No return value, prints a summary of the context level preference estimates to the console.
An autoMrP() object for which a summary is desired.
The level of the confidence intervals. A proportion. Default is
0.95. Confidence intervals are based on bootstrapped estimates and
will not be printed if bootstrapping was not carried out.
The number of digits to be displayed. An integer scalar.
Default is 4.
The table format. A character string passed to
kable. Default is simple.
Summarize a single classifier. A character string. Must be
one of best_subset, lasso, pca, gb, svm,
or mrp. Default is NULL.
Number of rows to be printed. An integer scalar. Default is
10.
Additional arguments affecting the summary produced.